@@ -1,14 +1,15 @@
-use strict;
-use warnings;
 package Dist::Zilla::Plugin::CoalescePod;
 BEGIN {
   $Dist::Zilla::Plugin::CoalescePod::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Dist::Zilla::Plugin::CoalescePod::VERSION = '0.1.0';
+  $Dist::Zilla::Plugin::CoalescePod::VERSION = '0.2.0';
 }
 # ABSTRACT: merge .pod files into their .pm counterparts
 
+use strict;
+use warnings;
+
 use Moose;
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -16,32 +17,40 @@ with 'Dist::Zilla::Role::FileMunger';
 sub munge_file {
     my ( $self, $file ) = @_;
 
-    return unless $file->name =~ /\.pm$/;
+    # only look under /lib
+    return unless $file->name =~ m#^lib/.*\.pm$#;
 
     ( my $podname = $file->name ) =~ s/\.pm$/.pod/;
 
     my ( $podfile ) = grep { $_->name eq $podname } 
                            @{ $self->zilla->files } or return;
 
-    $file->content(
-        $file->content . $podfile->content
-    );
+   $self->log( "merged $podfile into " . $file->name );
+
+    my @content = split /(^__DATA__$)/m, $file->content;
+
+    # inject the pod
+    splice @content, 1, 0, $podfile->content;
+
+    $file->content( join '', @content );
 
     $self->zilla->prune_file($podfile);
 }
 
 1;
+#PODNAME: Foo
 
 __END__
+
 =pod
 
 =head1 NAME
 
-Dist::Zilla::Plugin::CoalescePod - merge .pod files into their .pm counterparts
+Foo - merge .pod files into their .pm counterparts
 
 =head1 VERSION
 
-version 0.1.0
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -65,4 +74,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
